Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = BigtableInstanceAdmin::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_app_profiles()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Concrete implementations of this client library traits.
Structs
- Bigtable
Instance Admin - Implements a client for the Cloud Bigtable Admin API.
- Bigtable
Table Admin - Implements a client for the Cloud Bigtable Admin API.