pub struct BigtableInstanceAdmin { /* private fields */ }Expand description
Implements a client for the Cloud Bigtable Admin API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = BigtableInstanceAdmin::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_app_profiles()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for creating, configuring, and deleting Cloud Bigtable Instances and Clusters. Provides access to the Instance and Cluster schemas only, not the tables’ metadata or data stored in those tables.
Configuration
To configure BigtableInstanceAdmin use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://bigtableadmin.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
BigtableInstanceAdmin holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap BigtableInstanceAdmin in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl BigtableInstanceAdmin
impl BigtableInstanceAdmin
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for BigtableInstanceAdmin.
let client = BigtableInstanceAdmin::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: BigtableInstanceAdmin + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: BigtableInstanceAdmin + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_instance(&self) -> CreateInstance
pub fn create_instance(&self) -> CreateInstance
Create an instance within a project.
Note that exactly one of Cluster.serve_nodes and Cluster.cluster_config.cluster_autoscaling_config can be set. If serve_nodes is set to non-zero, then the cluster is manually scaled. If cluster_config.cluster_autoscaling_config is non-empty, then autoscaling is enabled.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_bigtable_admin_v2::model::Instance;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, parent: &str
) -> Result<()> {
let response = client.create_instance()
.set_parent(parent)
.set_instance_id("instance_id_value")
.set_instance(
Instance::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_instance(&self) -> GetInstance
pub fn get_instance(&self) -> GetInstance
Gets information about an instance.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
let response = client.get_instance()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_instances(&self) -> ListInstances
pub fn list_instances(&self) -> ListInstances
Lists information about instances in a project.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.list_instances()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_instance(&self) -> UpdateInstance
pub fn update_instance(&self) -> UpdateInstance
Updates an instance within a project. This method updates only the display name and type for an Instance. To update other Instance properties, such as labels, use PartialUpdateInstance.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.update_instance()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn partial_update_instance(&self) -> PartialUpdateInstance
pub fn partial_update_instance(&self) -> PartialUpdateInstance
Partially updates an instance within a project. This method can modify all fields of an Instance and is the preferred way to update an Instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.partial_update_instance()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_instance(&self) -> DeleteInstance
pub fn delete_instance(&self) -> DeleteInstance
Delete an instance from a project.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
client.delete_instance()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn create_cluster(&self) -> CreateCluster
pub fn create_cluster(&self) -> CreateCluster
Creates a cluster within an instance.
Note that exactly one of Cluster.serve_nodes and Cluster.cluster_config.cluster_autoscaling_config can be set. If serve_nodes is set to non-zero, then the cluster is manually scaled. If cluster_config.cluster_autoscaling_config is non-empty, then autoscaling is enabled.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_bigtable_admin_v2::model::Cluster;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, parent: &str
) -> Result<()> {
let response = client.create_cluster()
.set_parent(parent)
.set_cluster_id("cluster_id_value")
.set_cluster(
Cluster::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_cluster(&self) -> GetCluster
pub fn get_cluster(&self) -> GetCluster
Gets information about a cluster.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
let response = client.get_cluster()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_clusters(&self) -> ListClusters
pub fn list_clusters(&self) -> ListClusters
Lists information about clusters in an instance.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.list_clusters()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_cluster(&self) -> UpdateCluster
pub fn update_cluster(&self) -> UpdateCluster
Updates a cluster within an instance.
Note that UpdateCluster does not support updating cluster_config.cluster_autoscaling_config. In order to update it, you must use PartialUpdateCluster.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.update_cluster()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn partial_update_cluster(&self) -> PartialUpdateCluster
pub fn partial_update_cluster(&self) -> PartialUpdateCluster
Partially updates a cluster within a project. This method is the preferred way to update a Cluster.
To enable and update autoscaling, set cluster_config.cluster_autoscaling_config. When autoscaling is enabled, serve_nodes is treated as an OUTPUT_ONLY field, meaning that updates to it are ignored. Note that an update cannot simultaneously set serve_nodes to non-zero and cluster_config.cluster_autoscaling_config to non-empty, and also specify both in the update_mask.
To disable autoscaling, clear cluster_config.cluster_autoscaling_config, and explicitly set a serve_node count via the update_mask.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.partial_update_cluster()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_cluster(&self) -> DeleteCluster
pub fn delete_cluster(&self) -> DeleteCluster
Deletes a cluster from an instance.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
client.delete_cluster()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn create_app_profile(&self) -> CreateAppProfile
pub fn create_app_profile(&self) -> CreateAppProfile
Creates an app profile within an instance.
Example
use google_cloud_bigtable_admin_v2::model::AppProfile;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, parent: &str
) -> Result<()> {
let response = client.create_app_profile()
.set_parent(parent)
.set_app_profile(
AppProfile::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_app_profile(&self) -> GetAppProfile
pub fn get_app_profile(&self) -> GetAppProfile
Gets information about an app profile.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
let response = client.get_app_profile()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_app_profiles(&self) -> ListAppProfiles
pub fn list_app_profiles(&self) -> ListAppProfiles
Lists information about app profiles in an instance.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, parent: &str
) -> Result<()> {
let mut list = client.list_app_profiles()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_app_profile(&self) -> UpdateAppProfile
pub fn update_app_profile(&self) -> UpdateAppProfile
Updates an app profile within an instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_bigtable_admin_v2::model::AppProfile;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
let response = client.update_app_profile()
.set_app_profile(
AppProfile::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_app_profile(&self) -> DeleteAppProfile
pub fn delete_app_profile(&self) -> DeleteAppProfile
Deletes an app profile from an instance.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
client.delete_app_profile()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the access control policy for an instance resource. Returns an empty policy if an instance exists but does not have a policy set.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the access control policy on an instance resource. Replaces any existing policy.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn test_iam_permissions(&self) -> TestIamPermissions
pub fn test_iam_permissions(&self) -> TestIamPermissions
Returns permissions that the caller has on the specified instance resource.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.test_iam_permissions()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_hot_tablets(&self) -> ListHotTablets
pub fn list_hot_tablets(&self) -> ListHotTablets
Lists hot tablets in a cluster, within the time range provided. Hot tablets are ordered based on CPU usage.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, parent: &str
) -> Result<()> {
let mut list = client.list_hot_tablets()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn create_logical_view(&self) -> CreateLogicalView
pub fn create_logical_view(&self) -> CreateLogicalView
Creates a logical view within an instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_bigtable_admin_v2::model::LogicalView;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, parent: &str
) -> Result<()> {
let response = client.create_logical_view()
.set_parent(parent)
.set_logical_view(
LogicalView::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_logical_view(&self) -> GetLogicalView
pub fn get_logical_view(&self) -> GetLogicalView
Gets information about a logical view.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
let response = client.get_logical_view()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_logical_views(&self) -> ListLogicalViews
pub fn list_logical_views(&self) -> ListLogicalViews
Lists information about logical views in an instance.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, parent: &str
) -> Result<()> {
let mut list = client.list_logical_views()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_logical_view(&self) -> UpdateLogicalView
pub fn update_logical_view(&self) -> UpdateLogicalView
Updates a logical view within an instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_bigtable_admin_v2::model::LogicalView;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
let response = client.update_logical_view()
.set_logical_view(
LogicalView::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_logical_view(&self) -> DeleteLogicalView
pub fn delete_logical_view(&self) -> DeleteLogicalView
Deletes a logical view from an instance.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
client.delete_logical_view()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn create_materialized_view(&self) -> CreateMaterializedView
pub fn create_materialized_view(&self) -> CreateMaterializedView
Creates a materialized view within an instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_bigtable_admin_v2::model::MaterializedView;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, parent: &str
) -> Result<()> {
let response = client.create_materialized_view()
.set_parent(parent)
.set_materialized_view(
MaterializedView::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_materialized_view(&self) -> GetMaterializedView
pub fn get_materialized_view(&self) -> GetMaterializedView
Gets information about a materialized view.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
let response = client.get_materialized_view()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_materialized_views(&self) -> ListMaterializedViews
pub fn list_materialized_views(&self) -> ListMaterializedViews
Lists information about materialized views in an instance.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, parent: &str
) -> Result<()> {
let mut list = client.list_materialized_views()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn update_materialized_view(&self) -> UpdateMaterializedView
pub fn update_materialized_view(&self) -> UpdateMaterializedView
Updates a materialized view within an instance.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_bigtable_admin_v2::model::MaterializedView;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
let response = client.update_materialized_view()
.set_materialized_view(
MaterializedView::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_materialized_view(&self) -> DeleteMaterializedView
pub fn delete_materialized_view(&self) -> DeleteMaterializedView
Deletes a materialized view from an instance.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin, name: &str
) -> Result<()> {
client.delete_materialized_view()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_bigtable_admin_v2::Result;
async fn sample(
client: &BigtableInstanceAdmin
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for BigtableInstanceAdmin
impl Clone for BigtableInstanceAdmin
Sourcefn clone(&self) -> BigtableInstanceAdmin
fn clone(&self) -> BigtableInstanceAdmin
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more