Module authorized_view

Module authorized_view 

Defines additional types related to AuthorizedView.

Structs

FamilySubsets
Subsets of a column family that are included in this AuthorizedView.
SubsetView
Defines a simple AuthorizedView that is a subset of the underlying Table.

Enums

AuthorizedView
The type of this AuthorizedView.
ResponseView
Defines a subset of an AuthorizedView’s fields.