#[non_exhaustive]pub enum NodeScalingFactor {
Unspecified,
NodeScalingFactor1X,
NodeScalingFactor2X,
UnknownValue(UnknownValue),
}Expand description
Possible node scaling factors of the clusters. Node scaling delivers better latency and more throughput by removing node boundaries.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
No node scaling specified. Defaults to NODE_SCALING_FACTOR_1X.
NodeScalingFactor1X
The cluster is running with a scaling factor of 1.
NodeScalingFactor2X
The cluster is running with a scaling factor of 2. All node count values must be in increments of 2 with this scaling factor enabled, otherwise an INVALID_ARGUMENT error will be returned.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using NodeScalingFactor::value or NodeScalingFactor::name.
Implementations