An edition is a specific tier of Cloud Bigtable. Each edition is tailored
to different customer needs. Higher tiers offer more features and better
performance.
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
New values appearing in future releases of the client library, and
New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some
guidelines.
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The Enterprise Plus edition. This is a premium tier that is designed for
demanding, multi-tenant workloads requiring the highest levels of
performance, scale, and global availability.
The nodes in the Enterprise Plus tier come at a higher cost than the
Enterprise tier. Any Enterprise Plus features must be disabled before
downgrading to Enterprise.