#[non_exhaustive]pub struct Modification {
pub id: String,
pub update_mask: Option<FieldMask>,
pub mod: Option<Mod>,
/* private fields */
}Expand description
A create, update, or delete of a particular column family.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe ID of the column family to be modified.
update_mask: Option<FieldMask>Optional. A mask specifying which fields (e.g. gc_rule) in the update
mod should be updated, ignored for other modification types. If unset or
empty, we treat it as updating gc_rule to be backward compatible.
mod: Option<Mod>Column family modifications.
Implementations
Sourceimpl Modification
impl Modification
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = Modification::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = Modification::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = Modification::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn create(&self) -> Option<&Box<ColumnFamily>>
pub fn create(&self) -> Option<&Box<ColumnFamily>>
The value of [r#mod][crate::model::modify_column_families_request::Modification::r#mod]
if it holds a Create, None if the field is not set or
holds a different branch.
Sourcepub fn set_create<T: Into<Box<ColumnFamily>>>(self, v: T) -> Self
pub fn set_create<T: Into<Box<ColumnFamily>>>(self, v: T) -> Self
Sets the value of [r#mod][crate::model::modify_column_families_request::Modification::r#mod]
to hold a Create.
Note that all the setters affecting r#mod are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::ColumnFamily;
let x = Modification::new().set_create(ColumnFamily::default()/* use setters */);
assert!(x.create().is_some());
assert!(x.update().is_none());
assert!(x.drop().is_none());Sourcepub fn update(&self) -> Option<&Box<ColumnFamily>>
pub fn update(&self) -> Option<&Box<ColumnFamily>>
The value of [r#mod][crate::model::modify_column_families_request::Modification::r#mod]
if it holds a Update, None if the field is not set or
holds a different branch.
Sourcepub fn set_update<T: Into<Box<ColumnFamily>>>(self, v: T) -> Self
pub fn set_update<T: Into<Box<ColumnFamily>>>(self, v: T) -> Self
Sets the value of [r#mod][crate::model::modify_column_families_request::Modification::r#mod]
to hold a Update.
Note that all the setters affecting r#mod are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::ColumnFamily;
let x = Modification::new().set_update(ColumnFamily::default()/* use setters */);
assert!(x.update().is_some());
assert!(x.create().is_none());
assert!(x.drop().is_none());Sourcepub fn drop(&self) -> Option<&bool>
pub fn drop(&self) -> Option<&bool>
The value of [r#mod][crate::model::modify_column_families_request::Modification::r#mod]
if it holds a Drop, None if the field is not set or
holds a different branch.
Sourcepub fn set_drop<T: Into<bool>>(self, v: T) -> Self
pub fn set_drop<T: Into<bool>>(self, v: T) -> Self
Sets the value of [r#mod][crate::model::modify_column_families_request::Modification::r#mod]
to hold a Drop.
Note that all the setters affecting r#mod are
mutually exclusive.
Example
let x = Modification::new().set_drop(true);
assert!(x.drop().is_some());
assert!(x.create().is_none());
assert!(x.update().is_none());Trait Implementations
Sourceimpl Clone for Modification
impl Clone for Modification
Sourcefn clone(&self) -> Modification
fn clone(&self) -> Modification
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for Modification
impl Debug for Modification
Sourceimpl Default for Modification
impl Default for Modification
Sourcefn default() -> Modification
fn default() -> Modification
Sourceimpl Message for Modification
impl Message for Modification
Sourceimpl PartialEq for Modification
impl PartialEq for Modification
impl StructuralPartialEq for Modification