#[non_exhaustive]pub struct AppProfile {
pub name: String,
pub etag: String,
pub description: String,
pub routing_policy: Option<RoutingPolicy>,
pub isolation: Option<Isolation>,
/* private fields */
}Expand description
A configuration object describing how Cloud Bigtable should treat traffic from a particular end user application.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe unique name of the app profile. Values are of the form
projects/{project}/instances/{instance}/appProfiles/[_a-zA-Z0-9][-_.a-zA-Z0-9]*.
etag: StringStrongly validated etag for optimistic concurrency control. Preserve the
value returned from GetAppProfile when calling UpdateAppProfile to
fail the request if there has been a modification in the mean time. The
update_mask of the request need not include etag for this protection
to apply.
See Wikipedia and
RFC 7232 for more
details.
description: StringLong form description of the use case for this AppProfile.
routing_policy: Option<RoutingPolicy>The routing policy for all read/write requests that use this app profile. A value must be explicitly set.
isolation: Option<Isolation>Options for isolating this app profile’s traffic from other use cases.
Implementations
Sourceimpl AppProfile
impl AppProfile
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_routing_policy<T: Into<Option<RoutingPolicy>>>(self, v: T) -> Self
pub fn set_routing_policy<T: Into<Option<RoutingPolicy>>>(self, v: T) -> Self
Sets the value of routing_policy.
Note that all the setters affecting routing_policy are mutually
exclusive.
Example
use google_cloud_bigtable_admin_v2::model::app_profile::MultiClusterRoutingUseAny;
let x = AppProfile::new().set_routing_policy(Some(
google_cloud_bigtable_admin_v2::model::app_profile::RoutingPolicy::MultiClusterRoutingUseAny(MultiClusterRoutingUseAny::default().into())));Sourcepub fn multi_cluster_routing_use_any(
&self,
) -> Option<&Box<MultiClusterRoutingUseAny>>
pub fn multi_cluster_routing_use_any( &self, ) -> Option<&Box<MultiClusterRoutingUseAny>>
The value of routing_policy
if it holds a MultiClusterRoutingUseAny, None if the field is not set or
holds a different branch.
Sourcepub fn set_multi_cluster_routing_use_any<T: Into<Box<MultiClusterRoutingUseAny>>>(
self,
v: T,
) -> Self
pub fn set_multi_cluster_routing_use_any<T: Into<Box<MultiClusterRoutingUseAny>>>( self, v: T, ) -> Self
Sets the value of routing_policy
to hold a MultiClusterRoutingUseAny.
Note that all the setters affecting routing_policy are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::app_profile::MultiClusterRoutingUseAny;
let x = AppProfile::new().set_multi_cluster_routing_use_any(MultiClusterRoutingUseAny::default()/* use setters */);
assert!(x.multi_cluster_routing_use_any().is_some());
assert!(x.single_cluster_routing().is_none());Sourcepub fn single_cluster_routing(&self) -> Option<&Box<SingleClusterRouting>>
pub fn single_cluster_routing(&self) -> Option<&Box<SingleClusterRouting>>
The value of routing_policy
if it holds a SingleClusterRouting, None if the field is not set or
holds a different branch.
Sourcepub fn set_single_cluster_routing<T: Into<Box<SingleClusterRouting>>>(
self,
v: T,
) -> Self
pub fn set_single_cluster_routing<T: Into<Box<SingleClusterRouting>>>( self, v: T, ) -> Self
Sets the value of routing_policy
to hold a SingleClusterRouting.
Note that all the setters affecting routing_policy are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::app_profile::SingleClusterRouting;
let x = AppProfile::new().set_single_cluster_routing(SingleClusterRouting::default()/* use setters */);
assert!(x.single_cluster_routing().is_some());
assert!(x.multi_cluster_routing_use_any().is_none());Sourcepub fn set_isolation<T: Into<Option<Isolation>>>(self, v: T) -> Self
pub fn set_isolation<T: Into<Option<Isolation>>>(self, v: T) -> Self
Sets the value of isolation.
Note that all the setters affecting isolation are mutually
exclusive.
Example
use google_cloud_bigtable_admin_v2::model::app_profile::StandardIsolation;
let x = AppProfile::new().set_isolation(Some(
google_cloud_bigtable_admin_v2::model::app_profile::Isolation::StandardIsolation(StandardIsolation::default().into())));Sourcepub fn priority(&self) -> Option<&Priority>
👎Deprecated
pub fn priority(&self) -> Option<&Priority>
The value of isolation
if it holds a Priority, None if the field is not set or
holds a different branch.
Sourcepub fn set_priority<T: Into<Priority>>(self, v: T) -> Self
👎Deprecated
pub fn set_priority<T: Into<Priority>>(self, v: T) -> Self
Sets the value of isolation
to hold a Priority.
Note that all the setters affecting isolation are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::app_profile::Priority;
let x0 = AppProfile::new().set_priority(Priority::Low);
let x1 = AppProfile::new().set_priority(Priority::Medium);
let x2 = AppProfile::new().set_priority(Priority::High);
assert!(x0.priority().is_some());
assert!(x0.standard_isolation().is_none());
assert!(x0.data_boost_isolation_read_only().is_none());
assert!(x1.priority().is_some());
assert!(x1.standard_isolation().is_none());
assert!(x1.data_boost_isolation_read_only().is_none());
assert!(x2.priority().is_some());
assert!(x2.standard_isolation().is_none());
assert!(x2.data_boost_isolation_read_only().is_none());Sourcepub fn standard_isolation(&self) -> Option<&Box<StandardIsolation>>
pub fn standard_isolation(&self) -> Option<&Box<StandardIsolation>>
The value of isolation
if it holds a StandardIsolation, None if the field is not set or
holds a different branch.
Sourcepub fn set_standard_isolation<T: Into<Box<StandardIsolation>>>(
self,
v: T,
) -> Self
pub fn set_standard_isolation<T: Into<Box<StandardIsolation>>>( self, v: T, ) -> Self
Sets the value of isolation
to hold a StandardIsolation.
Note that all the setters affecting isolation are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::app_profile::StandardIsolation;
let x = AppProfile::new().set_standard_isolation(StandardIsolation::default()/* use setters */);
assert!(x.standard_isolation().is_some());
assert!(x.priority().is_none());
assert!(x.data_boost_isolation_read_only().is_none());Sourcepub fn data_boost_isolation_read_only(
&self,
) -> Option<&Box<DataBoostIsolationReadOnly>>
pub fn data_boost_isolation_read_only( &self, ) -> Option<&Box<DataBoostIsolationReadOnly>>
The value of isolation
if it holds a DataBoostIsolationReadOnly, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_boost_isolation_read_only<T: Into<Box<DataBoostIsolationReadOnly>>>(
self,
v: T,
) -> Self
pub fn set_data_boost_isolation_read_only<T: Into<Box<DataBoostIsolationReadOnly>>>( self, v: T, ) -> Self
Sets the value of isolation
to hold a DataBoostIsolationReadOnly.
Note that all the setters affecting isolation are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::app_profile::DataBoostIsolationReadOnly;
let x = AppProfile::new().set_data_boost_isolation_read_only(DataBoostIsolationReadOnly::default()/* use setters */);
assert!(x.data_boost_isolation_read_only().is_some());
assert!(x.priority().is_none());
assert!(x.standard_isolation().is_none());Trait Implementations
Sourceimpl Clone for AppProfile
impl Clone for AppProfile
Sourcefn clone(&self) -> AppProfile
fn clone(&self) -> AppProfile
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AppProfile
impl Debug for AppProfile
Sourceimpl Default for AppProfile
impl Default for AppProfile
Sourcefn default() -> AppProfile
fn default() -> AppProfile
Sourceimpl PartialEq for AppProfile
impl PartialEq for AppProfile
impl StructuralPartialEq for AppProfile