#[non_exhaustive]pub struct AuthorizedView {
pub name: String,
pub etag: String,
pub deletion_protection: bool,
pub authorized_view: Option<AuthorizedView>,
/* private fields */
}Expand description
AuthorizedViews represent subsets of a particular Cloud Bigtable table. Users can configure access to each Authorized View independently from the table and use the existing Data APIs to access the subset of data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The name of this AuthorizedView.
Values are of the form
projects/{project}/instances/{instance}/tables/{table}/authorizedViews/{authorized_view}
etag: StringThe etag for this AuthorizedView. If this is provided on update, it must match the server’s etag. The server returns ABORTED error on a mismatched etag.
deletion_protection: boolSet to true to make the AuthorizedView protected against deletion. The parent Table and containing Instance cannot be deleted if an AuthorizedView has this bit set.
The type of this AuthorizedView.
Implementations
Sourceimpl AuthorizedView
impl AuthorizedView
Sourcepub fn set_deletion_protection<T: Into<bool>>(self, v: T) -> Self
pub fn set_deletion_protection<T: Into<bool>>(self, v: T) -> Self
Sets the value of deletion_protection.
Example
let x = AuthorizedView::new().set_deletion_protection(true);Sets the value of authorized_view.
Note that all the setters affecting authorized_view are mutually
exclusive.
Example
use google_cloud_bigtable_admin_v2::model::authorized_view::SubsetView;
let x = AuthorizedView::new().set_authorized_view(Some(
google_cloud_bigtable_admin_v2::model::authorized_view::AuthorizedView::SubsetView(SubsetView::default().into())));Sourcepub fn subset_view(&self) -> Option<&Box<SubsetView>>
pub fn subset_view(&self) -> Option<&Box<SubsetView>>
The value of authorized_view
if it holds a SubsetView, None if the field is not set or
holds a different branch.
Sourcepub fn set_subset_view<T: Into<Box<SubsetView>>>(self, v: T) -> Self
pub fn set_subset_view<T: Into<Box<SubsetView>>>(self, v: T) -> Self
Sets the value of authorized_view
to hold a SubsetView.
Note that all the setters affecting authorized_view are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::authorized_view::SubsetView;
let x = AuthorizedView::new().set_subset_view(SubsetView::default()/* use setters */);
assert!(x.subset_view().is_some());Trait Implementations
Sourceimpl Clone for AuthorizedView
impl Clone for AuthorizedView
Sourcefn clone(&self) -> AuthorizedView
fn clone(&self) -> AuthorizedView
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AuthorizedView
impl Debug for AuthorizedView
Sourceimpl Default for AuthorizedView
impl Default for AuthorizedView
Sourcefn default() -> AuthorizedView
fn default() -> AuthorizedView
Sourceimpl Message for AuthorizedView
impl Message for AuthorizedView
Sourceimpl PartialEq for AuthorizedView
impl PartialEq for AuthorizedView
impl StructuralPartialEq for AuthorizedView