#[non_exhaustive]pub struct AutoscalingTargets {
pub cpu_utilization_percent: i32,
pub storage_utilization_gib_per_node: i32,
/* private fields */
}Expand description
The Autoscaling targets for a Cluster. These determine the recommended nodes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cpu_utilization_percent: i32The cpu utilization that the Autoscaler should be trying to achieve. This number is on a scale from 0 (no utilization) to 100 (total utilization), and is limited between 10 and 80, otherwise it will return INVALID_ARGUMENT error.
storage_utilization_gib_per_node: i32The storage utilization that the Autoscaler should be trying to achieve. This number is limited between 2560 (2.5TiB) and 5120 (5TiB) for a SSD cluster and between 8192 (8TiB) and 16384 (16TiB) for an HDD cluster, otherwise it will return INVALID_ARGUMENT error. If this value is set to 0, it will be treated as if it were set to the default value: 2560 for SSD, 8192 for HDD.
Implementations
Sourceimpl AutoscalingTargets
impl AutoscalingTargets
Sourcepub fn set_cpu_utilization_percent<T: Into<i32>>(self, v: T) -> Self
pub fn set_cpu_utilization_percent<T: Into<i32>>(self, v: T) -> Self
Sets the value of cpu_utilization_percent.
Example
let x = AutoscalingTargets::new().set_cpu_utilization_percent(42);Sourcepub fn set_storage_utilization_gib_per_node<T: Into<i32>>(self, v: T) -> Self
pub fn set_storage_utilization_gib_per_node<T: Into<i32>>(self, v: T) -> Self
Sets the value of storage_utilization_gib_per_node.
Example
let x = AutoscalingTargets::new().set_storage_utilization_gib_per_node(42);Trait Implementations
Sourceimpl Clone for AutoscalingTargets
impl Clone for AutoscalingTargets
Sourcefn clone(&self) -> AutoscalingTargets
fn clone(&self) -> AutoscalingTargets
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AutoscalingTargets
impl Debug for AutoscalingTargets
Sourceimpl Default for AutoscalingTargets
impl Default for AutoscalingTargets
Sourcefn default() -> AutoscalingTargets
fn default() -> AutoscalingTargets
Sourceimpl Message for AutoscalingTargets
impl Message for AutoscalingTargets
Sourceimpl PartialEq for AutoscalingTargets
impl PartialEq for AutoscalingTargets
impl StructuralPartialEq for AutoscalingTargets