#[non_exhaustive]pub struct CheckConsistencyRequest {
pub name: String,
pub consistency_token: String,
pub mode: Option<Mode>,
/* private fields */
}Expand description
Request message for google.bigtable.admin.v2.BigtableTableAdmin.CheckConsistency
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The unique name of the Table for which to check replication
consistency. Values are of the form
projects/{project}/instances/{instance}/tables/{table}.
consistency_token: StringRequired. The token created using GenerateConsistencyToken for the Table.
mode: Option<Mode>Which type of read needs to consistently observe which type of write?
Default: standard_read_remote_writes
Implementations
Sourceimpl CheckConsistencyRequest
impl CheckConsistencyRequest
Sourcepub fn set_consistency_token<T: Into<String>>(self, v: T) -> Self
pub fn set_consistency_token<T: Into<String>>(self, v: T) -> Self
Sets the value of consistency_token.
Example
let x = CheckConsistencyRequest::new().set_consistency_token("example");Sourcepub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
pub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
Sets the value of mode.
Note that all the setters affecting mode are mutually
exclusive.
Example
use google_cloud_bigtable_admin_v2::model::StandardReadRemoteWrites;
let x = CheckConsistencyRequest::new().set_mode(Some(
google_cloud_bigtable_admin_v2::model::check_consistency_request::Mode::StandardReadRemoteWrites(StandardReadRemoteWrites::default().into())));Sourcepub fn standard_read_remote_writes(
&self,
) -> Option<&Box<StandardReadRemoteWrites>>
pub fn standard_read_remote_writes( &self, ) -> Option<&Box<StandardReadRemoteWrites>>
The value of mode
if it holds a StandardReadRemoteWrites, None if the field is not set or
holds a different branch.
Sourcepub fn set_standard_read_remote_writes<T: Into<Box<StandardReadRemoteWrites>>>(
self,
v: T,
) -> Self
pub fn set_standard_read_remote_writes<T: Into<Box<StandardReadRemoteWrites>>>( self, v: T, ) -> Self
Sets the value of mode
to hold a StandardReadRemoteWrites.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::StandardReadRemoteWrites;
let x = CheckConsistencyRequest::new().set_standard_read_remote_writes(StandardReadRemoteWrites::default()/* use setters */);
assert!(x.standard_read_remote_writes().is_some());
assert!(x.data_boost_read_local_writes().is_none());Sourcepub fn data_boost_read_local_writes(
&self,
) -> Option<&Box<DataBoostReadLocalWrites>>
pub fn data_boost_read_local_writes( &self, ) -> Option<&Box<DataBoostReadLocalWrites>>
The value of mode
if it holds a DataBoostReadLocalWrites, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_boost_read_local_writes<T: Into<Box<DataBoostReadLocalWrites>>>(
self,
v: T,
) -> Self
pub fn set_data_boost_read_local_writes<T: Into<Box<DataBoostReadLocalWrites>>>( self, v: T, ) -> Self
Sets the value of mode
to hold a DataBoostReadLocalWrites.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::DataBoostReadLocalWrites;
let x = CheckConsistencyRequest::new().set_data_boost_read_local_writes(DataBoostReadLocalWrites::default()/* use setters */);
assert!(x.data_boost_read_local_writes().is_some());
assert!(x.standard_read_remote_writes().is_none());Trait Implementations
Sourceimpl Clone for CheckConsistencyRequest
impl Clone for CheckConsistencyRequest
Sourcefn clone(&self) -> CheckConsistencyRequest
fn clone(&self) -> CheckConsistencyRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CheckConsistencyRequest
impl Debug for CheckConsistencyRequest
Sourceimpl Default for CheckConsistencyRequest
impl Default for CheckConsistencyRequest
Sourcefn default() -> CheckConsistencyRequest
fn default() -> CheckConsistencyRequest
Sourceimpl Message for CheckConsistencyRequest
impl Message for CheckConsistencyRequest
Sourceimpl PartialEq for CheckConsistencyRequest
impl PartialEq for CheckConsistencyRequest
impl StructuralPartialEq for CheckConsistencyRequest