#[non_exhaustive]pub struct CopyBackupRequest {
pub parent: String,
pub backup_id: String,
pub source_backup: String,
pub expire_time: Option<Timestamp>,
/* private fields */
}Expand description
The request for CopyBackup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The name of the destination cluster that will contain the backup
copy. The cluster must already exist. Values are of the form:
projects/{project}/instances/{instance}/clusters/{cluster}.
backup_id: StringRequired. The id of the new backup. The backup_id along with parent
are combined as {parent}/backups/{backup_id} to create the full backup
name, of the form:
projects/{project}/instances/{instance}/clusters/{cluster}/backups/{backup_id}.
This string must be between 1 and 50 characters in length and match the
regex [a-zA-Z0-9][-.a-zA-Z0-9]*.
source_backup: StringRequired. The source backup to be copied from.
The source backup needs to be in READY state for it to be copied.
Copying a copied backup is not allowed.
Once CopyBackup is in progress, the source backup cannot be deleted or
cleaned up on expiration until CopyBackup is finished.
Values are of the form:
projects/<project>/instances/<instance>/clusters/<cluster>/backups/<backup>.
expire_time: Option<Timestamp>Required. Required. The expiration time of the copied backup with
microsecond granularity that must be at least 6 hours and at most 30 days
from the time the request is received. Once the expire_time has
passed, Cloud Bigtable will delete the backup and free the resources used
by the backup.
Implementations
Sourceimpl CopyBackupRequest
impl CopyBackupRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_backup_id<T: Into<String>>(self, v: T) -> Self
pub fn set_backup_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_source_backup<T: Into<String>>(self, v: T) -> Self
pub fn set_source_backup<T: Into<String>>(self, v: T) -> Self
Sets the value of source_backup.
Example
let x = CopyBackupRequest::new().set_source_backup(format!("projects/{project_id}/instances/{instance_id}/clusters/{cluster_id}/backups/{backup_id}"));Sourcepub fn set_expire_time<T>(self, v: T) -> Self
pub fn set_expire_time<T>(self, v: T) -> Self
Sets the value of expire_time.
Example
use wkt::Timestamp;
let x = CopyBackupRequest::new().set_expire_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_expire_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_expire_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of expire_time.
Example
use wkt::Timestamp;
let x = CopyBackupRequest::new().set_or_clear_expire_time(Some(Timestamp::default()/* use setters */));
let x = CopyBackupRequest::new().set_or_clear_expire_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for CopyBackupRequest
impl Clone for CopyBackupRequest
Sourcefn clone(&self) -> CopyBackupRequest
fn clone(&self) -> CopyBackupRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CopyBackupRequest
impl Debug for CopyBackupRequest
Sourceimpl Default for CopyBackupRequest
impl Default for CopyBackupRequest
Sourcefn default() -> CopyBackupRequest
fn default() -> CopyBackupRequest
Sourceimpl Message for CopyBackupRequest
impl Message for CopyBackupRequest
Sourceimpl PartialEq for CopyBackupRequest
impl PartialEq for CopyBackupRequest
impl StructuralPartialEq for CopyBackupRequest