#[non_exhaustive]pub struct CreateClusterMetadata {
pub original_request: Option<CreateClusterRequest>,
pub request_time: Option<Timestamp>,
pub finish_time: Option<Timestamp>,
pub tables: HashMap<String, TableProgress>,
/* private fields */
}Expand description
The metadata for the Operation returned by CreateCluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.original_request: Option<CreateClusterRequest>The request that prompted the initiation of this CreateCluster operation.
request_time: Option<Timestamp>The time at which the original request was received.
finish_time: Option<Timestamp>The time at which the operation failed or was completed successfully.
tables: HashMap<String, TableProgress>Keys: the full name of each table that existed in the instance when
CreateCluster was first called, i.e.
projects/<project>/instances/<instance>/tables/<table>. Any table added
to the instance by a later API call will be created in the new cluster by
that API call, not this one.
Values: information on how much of a table’s data has been copied to the newly-created cluster so far.
Implementations
Sourceimpl CreateClusterMetadata
impl CreateClusterMetadata
Sourcepub fn set_original_request<T>(self, v: T) -> Selfwhere
T: Into<CreateClusterRequest>,
pub fn set_original_request<T>(self, v: T) -> Selfwhere
T: Into<CreateClusterRequest>,
Sets the value of original_request.
Example
use google_cloud_bigtable_admin_v2::model::CreateClusterRequest;
let x = CreateClusterMetadata::new().set_original_request(CreateClusterRequest::default()/* use setters */);Sourcepub fn set_or_clear_original_request<T>(self, v: Option<T>) -> Selfwhere
T: Into<CreateClusterRequest>,
pub fn set_or_clear_original_request<T>(self, v: Option<T>) -> Selfwhere
T: Into<CreateClusterRequest>,
Sets or clears the value of original_request.
Example
use google_cloud_bigtable_admin_v2::model::CreateClusterRequest;
let x = CreateClusterMetadata::new().set_or_clear_original_request(Some(CreateClusterRequest::default()/* use setters */));
let x = CreateClusterMetadata::new().set_or_clear_original_request(None::<CreateClusterRequest>);Sourcepub fn set_request_time<T>(self, v: T) -> Self
pub fn set_request_time<T>(self, v: T) -> Self
Sets the value of request_time.
Example
use wkt::Timestamp;
let x = CreateClusterMetadata::new().set_request_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_request_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_time.
Example
use wkt::Timestamp;
let x = CreateClusterMetadata::new().set_or_clear_request_time(Some(Timestamp::default()/* use setters */));
let x = CreateClusterMetadata::new().set_or_clear_request_time(None::<Timestamp>);Sourcepub fn set_finish_time<T>(self, v: T) -> Self
pub fn set_finish_time<T>(self, v: T) -> Self
Sets the value of finish_time.
Example
use wkt::Timestamp;
let x = CreateClusterMetadata::new().set_finish_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_finish_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_finish_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of finish_time.
Example
use wkt::Timestamp;
let x = CreateClusterMetadata::new().set_or_clear_finish_time(Some(Timestamp::default()/* use setters */));
let x = CreateClusterMetadata::new().set_or_clear_finish_time(None::<Timestamp>);Sourcepub fn set_tables<T, K, V>(self, v: T) -> Self
pub fn set_tables<T, K, V>(self, v: T) -> Self