#[non_exhaustive]pub struct CreateTableFromSnapshotMetadata {
pub original_request: Option<CreateTableFromSnapshotRequest>,
pub request_time: Option<Timestamp>,
pub finish_time: Option<Timestamp>,
/* private fields */
}Expand description
The metadata for the Operation returned by CreateTableFromSnapshot.
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.original_request: Option<CreateTableFromSnapshotRequest>The request that prompted the initiation of this CreateTableFromSnapshot operation.
request_time: Option<Timestamp>The time at which the original request was received.
finish_time: Option<Timestamp>The time at which the operation failed or was completed successfully.
Implementations
Sourceimpl CreateTableFromSnapshotMetadata
impl CreateTableFromSnapshotMetadata
Sourcepub fn set_original_request<T>(self, v: T) -> Selfwhere
T: Into<CreateTableFromSnapshotRequest>,
pub fn set_original_request<T>(self, v: T) -> Selfwhere
T: Into<CreateTableFromSnapshotRequest>,
Sets the value of original_request.
Example
use google_cloud_bigtable_admin_v2::model::CreateTableFromSnapshotRequest;
let x = CreateTableFromSnapshotMetadata::new().set_original_request(CreateTableFromSnapshotRequest::default()/* use setters */);Sourcepub fn set_or_clear_original_request<T>(self, v: Option<T>) -> Selfwhere
T: Into<CreateTableFromSnapshotRequest>,
pub fn set_or_clear_original_request<T>(self, v: Option<T>) -> Selfwhere
T: Into<CreateTableFromSnapshotRequest>,
Sets or clears the value of original_request.
Example
use google_cloud_bigtable_admin_v2::model::CreateTableFromSnapshotRequest;
let x = CreateTableFromSnapshotMetadata::new().set_or_clear_original_request(Some(CreateTableFromSnapshotRequest::default()/* use setters */));
let x = CreateTableFromSnapshotMetadata::new().set_or_clear_original_request(None::<CreateTableFromSnapshotRequest>);Sourcepub fn set_request_time<T>(self, v: T) -> Self
pub fn set_request_time<T>(self, v: T) -> Self
Sets the value of request_time.
Example
use wkt::Timestamp;
let x = CreateTableFromSnapshotMetadata::new().set_request_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_request_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_time.
Example
use wkt::Timestamp;
let x = CreateTableFromSnapshotMetadata::new().set_or_clear_request_time(Some(Timestamp::default()/* use setters */));
let x = CreateTableFromSnapshotMetadata::new().set_or_clear_request_time(None::<Timestamp>);Sourcepub fn set_finish_time<T>(self, v: T) -> Self
pub fn set_finish_time<T>(self, v: T) -> Self
Sets the value of finish_time.
Example
use wkt::Timestamp;
let x = CreateTableFromSnapshotMetadata::new().set_finish_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_finish_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_finish_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of finish_time.
Example
use wkt::Timestamp;
let x = CreateTableFromSnapshotMetadata::new().set_or_clear_finish_time(Some(Timestamp::default()/* use setters */));
let x = CreateTableFromSnapshotMetadata::new().set_or_clear_finish_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for CreateTableFromSnapshotMetadata
impl Clone for CreateTableFromSnapshotMetadata
Sourcefn clone(&self) -> CreateTableFromSnapshotMetadata
fn clone(&self) -> CreateTableFromSnapshotMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateTableFromSnapshotMetadata
impl Default for CreateTableFromSnapshotMetadata
Sourcefn default() -> CreateTableFromSnapshotMetadata
fn default() -> CreateTableFromSnapshotMetadata
impl StructuralPartialEq for CreateTableFromSnapshotMetadata