#[non_exhaustive]pub struct CreateTableFromSnapshotRequest {
pub parent: String,
pub table_id: String,
pub source_snapshot: String,
/* private fields */
}Expand description
Request message for google.bigtable.admin.v2.BigtableTableAdmin.CreateTableFromSnapshot
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The unique name of the instance in which to create the table.
Values are of the form projects/{project}/instances/{instance}.
table_id: StringRequired. The name by which the new table should be referred to within the
parent instance, e.g., foobar rather than {parent}/tables/foobar.
source_snapshot: StringRequired. The unique name of the snapshot from which to restore the table.
The snapshot and the table must be in the same instance. Values are of the
form
projects/{project}/instances/{instance}/clusters/{cluster}/snapshots/{snapshot}.
Implementations
Sourceimpl CreateTableFromSnapshotRequest
impl CreateTableFromSnapshotRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_table_id<T: Into<String>>(self, v: T) -> Self
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_source_snapshot<T: Into<String>>(self, v: T) -> Self
pub fn set_source_snapshot<T: Into<String>>(self, v: T) -> Self
Sets the value of source_snapshot.
Example
let x = CreateTableFromSnapshotRequest::new().set_source_snapshot(format!("projects/{project_id}/instances/{instance_id}/clusters/{cluster_id}/snapshots/{snapshot_id}"));Trait Implementations
Sourceimpl Clone for CreateTableFromSnapshotRequest
impl Clone for CreateTableFromSnapshotRequest
Sourcefn clone(&self) -> CreateTableFromSnapshotRequest
fn clone(&self) -> CreateTableFromSnapshotRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateTableFromSnapshotRequest
impl Default for CreateTableFromSnapshotRequest
Sourcefn default() -> CreateTableFromSnapshotRequest
fn default() -> CreateTableFromSnapshotRequest
impl StructuralPartialEq for CreateTableFromSnapshotRequest