#[non_exhaustive]pub struct HotTablet {
pub name: String,
pub table_name: String,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub start_key: String,
pub end_key: String,
pub node_cpu_usage_percent: f32,
/* private fields */
}Expand description
A tablet is a defined by a start and end key and is explained in https://cloud.google.com/bigtable/docs/overview#architecture and https://cloud.google.com/bigtable/docs/performance#optimization. A Hot tablet is a tablet that exhibits high average cpu usage during the time interval from start time to end time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe unique name of the hot tablet. Values are of the form
projects/{project}/instances/{instance}/clusters/{cluster}/hotTablets/[a-zA-Z0-9_-]*.
table_name: StringName of the table that contains the tablet. Values are of the form
projects/{project}/instances/{instance}/tables/[_a-zA-Z0-9][-_.a-zA-Z0-9]*.
start_time: Option<Timestamp>Output only. The start time of the hot tablet.
end_time: Option<Timestamp>Output only. The end time of the hot tablet.
start_key: StringTablet Start Key (inclusive).
end_key: StringTablet End Key (inclusive).
node_cpu_usage_percent: f32Output only. The average CPU usage spent by a node on this tablet over the start_time to end_time time range. The percentage is the amount of CPU used by the node to serve the tablet, from 0% (tablet was not interacted with) to 100% (the node spent all cycles serving the hot tablet).
Implementations
Sourceimpl HotTablet
impl HotTablet
Sourcepub fn set_table_name<T: Into<String>>(self, v: T) -> Self
pub fn set_table_name<T: Into<String>>(self, v: T) -> Self
Sets the value of table_name.
Example
let x = HotTablet::new().set_table_name(format!("projects/{project_id}/instances/{instance_id}/tables/{table_id}"));Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = HotTablet::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = HotTablet::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = HotTablet::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_start_key<T: Into<String>>(self, v: T) -> Self
pub fn set_start_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_end_key<T: Into<String>>(self, v: T) -> Self
pub fn set_end_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_node_cpu_usage_percent<T: Into<f32>>(self, v: T) -> Self
pub fn set_node_cpu_usage_percent<T: Into<f32>>(self, v: T) -> Self
Sets the value of node_cpu_usage_percent.
Example
let x = HotTablet::new().set_node_cpu_usage_percent(42.0);Trait Implementations
impl StructuralPartialEq for HotTablet