#[non_exhaustive]pub struct Instance {
pub name: String,
pub display_name: String,
pub state: State,
pub type: Type,
pub edition: Edition,
pub labels: HashMap<String, String>,
pub create_time: Option<Timestamp>,
pub satisfies_pzs: Option<bool>,
pub satisfies_pzi: Option<bool>,
pub tags: HashMap<String, String>,
/* private fields */
}Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe unique name of the instance. Values are of the form
projects/{project}/instances/[a-z][a-z0-9\\-]+[a-z0-9].
display_name: StringRequired. The descriptive name for this instance as it appears in UIs. Can be changed at any time, but should be kept globally unique to avoid confusion.
state: StateOutput only. The current state of the instance.
type: TypeThe type of the instance. Defaults to PRODUCTION.
edition: EditionOptional. The edition of the instance. See Edition for details.
labels: HashMap<String, String>Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer’s organizational needs and deployment strategies. They can be used to filter resources and aggregate metrics.
- Label keys must be between 1 and 63 characters long and must conform to
the regular expression:
[\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}. - Label values must be between 0 and 63 characters long and must conform to
the regular expression:
[\p{Ll}\p{Lo}\p{N}_-]{0,63}. - No more than 64 labels can be associated with a given resource.
- Keys and values must both be under 128 bytes.
create_time: Option<Timestamp>Output only. A commit timestamp representing when this Instance was
created. For instances created before this field was added (August 2021),
this value is seconds: 0, nanos: 1.
satisfies_pzs: Option<bool>Output only. Reserved for future use.
satisfies_pzi: Option<bool>Output only. Reserved for future use.
Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example:
- “123/environment”: “production”,
- “123/costCenter”: “marketing”
Tags and Labels (above) are both used to bind metadata to resources, with different use-cases. See https://cloud.google.com/resource-manager/docs/tags/tags-overview for an in-depth overview on the difference between tags and labels.
Implementations
Sourceimpl Instance
impl Instance
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_edition<T: Into<Edition>>(self, v: T) -> Self
pub fn set_edition<T: Into<Edition>>(self, v: T) -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_satisfies_pzs<T>(self, v: T) -> Self
pub fn set_satisfies_pzs<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzs<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzs.
Example
let x = Instance::new().set_or_clear_satisfies_pzs(Some(false));
let x = Instance::new().set_or_clear_satisfies_pzs(None::<bool>);Sourcepub fn set_satisfies_pzi<T>(self, v: T) -> Self
pub fn set_satisfies_pzi<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_satisfies_pzi<T>(self, v: Option<T>) -> Self
Sets or clears the value of satisfies_pzi.
Example
let x = Instance::new().set_or_clear_satisfies_pzi(Some(false));
let x = Instance::new().set_or_clear_satisfies_pzi(None::<bool>);Trait Implementations
impl StructuralPartialEq for Instance