#[non_exhaustive]pub struct ListSnapshotsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for google.bigtable.admin.v2.BigtableTableAdmin.ListSnapshots
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The unique name of the cluster for which snapshots should be
listed. Values are of the form
projects/{project}/instances/{instance}/clusters/{cluster}.
Use {cluster} = '-' to list snapshots for all clusters in an instance,
e.g., projects/{project}/instances/{instance}/clusters/-.
page_size: i32The maximum number of snapshots to return per page. CURRENTLY UNIMPLEMENTED AND IGNORED.
page_token: StringThe value of next_page_token returned by a previous call.
Implementations
Sourceimpl ListSnapshotsRequest
impl ListSnapshotsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListSnapshotsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListSnapshotsRequest
impl Clone for ListSnapshotsRequest
Sourcefn clone(&self) -> ListSnapshotsRequest
fn clone(&self) -> ListSnapshotsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListSnapshotsRequest
impl Debug for ListSnapshotsRequest
Sourceimpl Default for ListSnapshotsRequest
impl Default for ListSnapshotsRequest
Sourcefn default() -> ListSnapshotsRequest
fn default() -> ListSnapshotsRequest
Sourceimpl Message for ListSnapshotsRequest
impl Message for ListSnapshotsRequest
Sourceimpl PartialEq for ListSnapshotsRequest
impl PartialEq for ListSnapshotsRequest
impl StructuralPartialEq for ListSnapshotsRequest