#[non_exhaustive]pub struct ListTablesRequest {
pub parent: String,
pub view: View,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for google.bigtable.admin.v2.BigtableTableAdmin.ListTables
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The unique name of the instance for which tables should be
listed. Values are of the form projects/{project}/instances/{instance}.
view: ViewThe view to be applied to the returned tables’ fields. NAME_ONLY view (default) and REPLICATION_VIEW are supported.
page_size: i32Maximum number of results per page.
A page_size of zero lets the server choose the number of items to return. A page_size which is strictly positive will return at most that many items. A negative page_size will cause an error.
Following the first request, subsequent paginated calls are not required to pass a page_size. If a page_size is set in subsequent calls, it must match the page_size given in the first request.
page_token: StringThe value of next_page_token returned by a previous call.
Implementations
Sourceimpl ListTablesRequest
impl ListTablesRequest