#[non_exhaustive]pub struct RestoreTableMetadata {
pub name: String,
pub source_type: RestoreSourceType,
pub optimize_table_operation_name: String,
pub progress: Option<OperationProgress>,
pub source_info: Option<SourceInfo>,
/* private fields */
}Expand description
Metadata type for the long-running operation returned by RestoreTable.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the table being created and restored to.
source_type: RestoreSourceTypeThe type of the restore source.
optimize_table_operation_name: StringIf exists, the name of the long-running operation that will be used to track the post-restore optimization process to optimize the performance of the restored table. The metadata type of the long-running operation is [OptimizeRestoreTableMetadata][]. The response type is [Empty][google.protobuf.Empty]. This long-running operation may be automatically created by the system if applicable after the RestoreTable long-running operation completes successfully. This operation may not be created if the table is already optimized or the restore was not successful.
progress: Option<OperationProgress>The progress of the RestoreTable operation.
source_info: Option<SourceInfo>Information about the source used to restore the table, as specified by
source in
RestoreTableRequest.
Implementations
Sourceimpl RestoreTableMetadata
impl RestoreTableMetadata
Sourcepub fn set_source_type<T: Into<RestoreSourceType>>(self, v: T) -> Self
pub fn set_source_type<T: Into<RestoreSourceType>>(self, v: T) -> Self
Sets the value of source_type.
Example
use google_cloud_bigtable_admin_v2::model::RestoreSourceType;
let x0 = RestoreTableMetadata::new().set_source_type(RestoreSourceType::Backup);Sourcepub fn set_optimize_table_operation_name<T: Into<String>>(self, v: T) -> Self
pub fn set_optimize_table_operation_name<T: Into<String>>(self, v: T) -> Self
Sets the value of optimize_table_operation_name.
Example
let x = RestoreTableMetadata::new().set_optimize_table_operation_name("example");Sourcepub fn set_progress<T>(self, v: T) -> Selfwhere
T: Into<OperationProgress>,
pub fn set_progress<T>(self, v: T) -> Selfwhere
T: Into<OperationProgress>,
Sourcepub fn set_or_clear_progress<T>(self, v: Option<T>) -> Selfwhere
T: Into<OperationProgress>,
pub fn set_or_clear_progress<T>(self, v: Option<T>) -> Selfwhere
T: Into<OperationProgress>,
Sets or clears the value of progress.
Example
use google_cloud_bigtable_admin_v2::model::OperationProgress;
let x = RestoreTableMetadata::new().set_or_clear_progress(Some(OperationProgress::default()/* use setters */));
let x = RestoreTableMetadata::new().set_or_clear_progress(None::<OperationProgress>);Sourcepub fn set_source_info<T: Into<Option<SourceInfo>>>(self, v: T) -> Self
pub fn set_source_info<T: Into<Option<SourceInfo>>>(self, v: T) -> Self
Sets the value of source_info.
Note that all the setters affecting source_info are mutually
exclusive.
Example
use google_cloud_bigtable_admin_v2::model::BackupInfo;
let x = RestoreTableMetadata::new().set_source_info(Some(
google_cloud_bigtable_admin_v2::model::restore_table_metadata::SourceInfo::BackupInfo(BackupInfo::default().into())));Sourcepub fn backup_info(&self) -> Option<&Box<BackupInfo>>
pub fn backup_info(&self) -> Option<&Box<BackupInfo>>
The value of source_info
if it holds a BackupInfo, None if the field is not set or
holds a different branch.
Sourcepub fn set_backup_info<T: Into<Box<BackupInfo>>>(self, v: T) -> Self
pub fn set_backup_info<T: Into<Box<BackupInfo>>>(self, v: T) -> Self
Sets the value of source_info
to hold a BackupInfo.
Note that all the setters affecting source_info are
mutually exclusive.
Example
use google_cloud_bigtable_admin_v2::model::BackupInfo;
let x = RestoreTableMetadata::new().set_backup_info(BackupInfo::default()/* use setters */);
assert!(x.backup_info().is_some());Trait Implementations
Sourceimpl Clone for RestoreTableMetadata
impl Clone for RestoreTableMetadata
Sourcefn clone(&self) -> RestoreTableMetadata
fn clone(&self) -> RestoreTableMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RestoreTableMetadata
impl Debug for RestoreTableMetadata
Sourceimpl Default for RestoreTableMetadata
impl Default for RestoreTableMetadata
Sourcefn default() -> RestoreTableMetadata
fn default() -> RestoreTableMetadata
Sourceimpl Message for RestoreTableMetadata
impl Message for RestoreTableMetadata
Sourceimpl PartialEq for RestoreTableMetadata
impl PartialEq for RestoreTableMetadata
impl StructuralPartialEq for RestoreTableMetadata