#[non_exhaustive]pub struct SnapshotTableMetadata {
pub original_request: Option<SnapshotTableRequest>,
pub request_time: Option<Timestamp>,
pub finish_time: Option<Timestamp>,
/* private fields */
}Expand description
The metadata for the Operation returned by SnapshotTable.
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.original_request: Option<SnapshotTableRequest>The request that prompted the initiation of this SnapshotTable operation.
request_time: Option<Timestamp>The time at which the original request was received.
finish_time: Option<Timestamp>The time at which the operation failed or was completed successfully.
Implementations
Sourceimpl SnapshotTableMetadata
impl SnapshotTableMetadata
Sourcepub fn set_original_request<T>(self, v: T) -> Selfwhere
T: Into<SnapshotTableRequest>,
pub fn set_original_request<T>(self, v: T) -> Selfwhere
T: Into<SnapshotTableRequest>,
Sets the value of original_request.
Example
use google_cloud_bigtable_admin_v2::model::SnapshotTableRequest;
let x = SnapshotTableMetadata::new().set_original_request(SnapshotTableRequest::default()/* use setters */);Sourcepub fn set_or_clear_original_request<T>(self, v: Option<T>) -> Selfwhere
T: Into<SnapshotTableRequest>,
pub fn set_or_clear_original_request<T>(self, v: Option<T>) -> Selfwhere
T: Into<SnapshotTableRequest>,
Sets or clears the value of original_request.
Example
use google_cloud_bigtable_admin_v2::model::SnapshotTableRequest;
let x = SnapshotTableMetadata::new().set_or_clear_original_request(Some(SnapshotTableRequest::default()/* use setters */));
let x = SnapshotTableMetadata::new().set_or_clear_original_request(None::<SnapshotTableRequest>);Sourcepub fn set_request_time<T>(self, v: T) -> Self
pub fn set_request_time<T>(self, v: T) -> Self
Sets the value of request_time.
Example
use wkt::Timestamp;
let x = SnapshotTableMetadata::new().set_request_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_request_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_time.
Example
use wkt::Timestamp;
let x = SnapshotTableMetadata::new().set_or_clear_request_time(Some(Timestamp::default()/* use setters */));
let x = SnapshotTableMetadata::new().set_or_clear_request_time(None::<Timestamp>);Sourcepub fn set_finish_time<T>(self, v: T) -> Self
pub fn set_finish_time<T>(self, v: T) -> Self
Sets the value of finish_time.
Example
use wkt::Timestamp;
let x = SnapshotTableMetadata::new().set_finish_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_finish_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_finish_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of finish_time.
Example
use wkt::Timestamp;
let x = SnapshotTableMetadata::new().set_or_clear_finish_time(Some(Timestamp::default()/* use setters */));
let x = SnapshotTableMetadata::new().set_or_clear_finish_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for SnapshotTableMetadata
impl Clone for SnapshotTableMetadata
Sourcefn clone(&self) -> SnapshotTableMetadata
fn clone(&self) -> SnapshotTableMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SnapshotTableMetadata
impl Debug for SnapshotTableMetadata
Sourceimpl Default for SnapshotTableMetadata
impl Default for SnapshotTableMetadata
Sourcefn default() -> SnapshotTableMetadata
fn default() -> SnapshotTableMetadata
Sourceimpl Message for SnapshotTableMetadata
impl Message for SnapshotTableMetadata
Sourceimpl PartialEq for SnapshotTableMetadata
impl PartialEq for SnapshotTableMetadata
impl StructuralPartialEq for SnapshotTableMetadata