#[non_exhaustive]pub struct SnapshotTableRequest {
pub name: String,
pub cluster: String,
pub snapshot_id: String,
pub ttl: Option<Duration>,
pub description: String,
/* private fields */
}Expand description
Request message for google.bigtable.admin.v2.BigtableTableAdmin.SnapshotTable
Note: This is a private alpha release of Cloud Bigtable snapshots. This feature is not currently available to most Cloud Bigtable customers. This feature might be changed in backward-incompatible ways and is not recommended for production use. It is not subject to any SLA or deprecation policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The unique name of the table to have the snapshot taken.
Values are of the form
projects/{project}/instances/{instance}/tables/{table}.
cluster: StringRequired. The name of the cluster where the snapshot will be created in.
Values are of the form
projects/{project}/instances/{instance}/clusters/{cluster}.
snapshot_id: StringRequired. The ID by which the new snapshot should be referred to within the
parent cluster, e.g., mysnapshot of the form:
[_a-zA-Z0-9][-_.a-zA-Z0-9]* rather than
projects/{project}/instances/{instance}/clusters/{cluster}/snapshots/mysnapshot.
ttl: Option<Duration>The amount of time that the new snapshot can stay active after it is created. Once ‘ttl’ expires, the snapshot will get deleted. The maximum amount of time a snapshot can stay active is 7 days. If ‘ttl’ is not specified, the default value of 24 hours will be used.
description: StringDescription of the snapshot.
Implementations
Sourceimpl SnapshotTableRequest
impl SnapshotTableRequest
Sourcepub fn set_cluster<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_snapshot_id<T: Into<String>>(self, v: T) -> Self
pub fn set_snapshot_id<T: Into<String>>(self, v: T) -> Self
Sets the value of snapshot_id.
Example
let x = SnapshotTableRequest::new().set_snapshot_id("example");Sourcepub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_ttl<T>(self, v: Option<T>) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = SnapshotTableRequest::new().set_description("example");Trait Implementations
Sourceimpl Clone for SnapshotTableRequest
impl Clone for SnapshotTableRequest
Sourcefn clone(&self) -> SnapshotTableRequest
fn clone(&self) -> SnapshotTableRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SnapshotTableRequest
impl Debug for SnapshotTableRequest
Sourceimpl Default for SnapshotTableRequest
impl Default for SnapshotTableRequest
Sourcefn default() -> SnapshotTableRequest
fn default() -> SnapshotTableRequest
Sourceimpl Message for SnapshotTableRequest
impl Message for SnapshotTableRequest
Sourceimpl PartialEq for SnapshotTableRequest
impl PartialEq for SnapshotTableRequest
impl StructuralPartialEq for SnapshotTableRequest