TieredStorageConfig

Struct TieredStorageConfig 

#[non_exhaustive]
pub struct TieredStorageConfig { pub infrequent_access: Option<TieredStorageRule>, /* private fields */ }
Config for tiered storage. A valid config must have a valid TieredStorageRule. Otherwise the whole TieredStorageConfig must be unset. By default all data is stored in the SSD tier (only SSD instances can configure tiered storage).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
infrequent_access: Option<TieredStorageRule>

Rule to specify what data is stored in the infrequent access(IA) tier. The IA tier allows storing more data per node with reduced performance.

Implementations

Source

impl TieredStorageConfig

pub fn new() -> Self

pub fn set_infrequent_access<T>(self, v: T) -> Self

Sets the value of infrequent_access.

Example
use google_cloud_bigtable_admin_v2::model::TieredStorageRule;
let x = TieredStorageConfig::new().set_infrequent_access(TieredStorageRule::default()/* use setters */);
pub fn set_or_clear_infrequent_access<T>(self, v: Option<T>) -> Self

Sets or clears the value of infrequent_access.

Example
use google_cloud_bigtable_admin_v2::model::TieredStorageRule;
let x = TieredStorageConfig::new().set_or_clear_infrequent_access(Some(TieredStorageRule::default()/* use setters */));
let x = TieredStorageConfig::new().set_or_clear_infrequent_access(None::<TieredStorageRule>);