#[non_exhaustive]pub struct TieredStorageRule {
pub rule: Option<Rule>,
/* private fields */
}Expand description
Rule to specify what data is stored in a storage tier.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule: Option<Rule>Rules to specify what data is stored in this tier.
Implementations
Sourceimpl TieredStorageRule
impl TieredStorageRule
pub fn new() -> Self
Sourcepub fn include_if_older_than(&self) -> Option<&Box<Duration>>
pub fn include_if_older_than(&self) -> Option<&Box<Duration>>
The value of rule
if it holds a IncludeIfOlderThan, None if the field is not set or
holds a different branch.
Sourcepub fn set_include_if_older_than<T: Into<Box<Duration>>>(self, v: T) -> Self
pub fn set_include_if_older_than<T: Into<Box<Duration>>>(self, v: T) -> Self