#[non_exhaustive]pub struct UpdateAuthorizedViewMetadata {
pub original_request: Option<UpdateAuthorizedViewRequest>,
pub request_time: Option<Timestamp>,
pub finish_time: Option<Timestamp>,
/* private fields */
}Expand description
Metadata for the google.longrunning.Operation returned by UpdateAuthorizedView.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.original_request: Option<UpdateAuthorizedViewRequest>The request that prompted the initiation of this UpdateAuthorizedView operation.
request_time: Option<Timestamp>The time at which the original request was received.
finish_time: Option<Timestamp>The time at which the operation failed or was completed successfully.
Implementations
Sourceimpl UpdateAuthorizedViewMetadata
impl UpdateAuthorizedViewMetadata
Sourcepub fn set_original_request<T>(self, v: T) -> Selfwhere
T: Into<UpdateAuthorizedViewRequest>,
pub fn set_original_request<T>(self, v: T) -> Selfwhere
T: Into<UpdateAuthorizedViewRequest>,
Sets the value of original_request.
Example
ⓘ
use google_cloud_bigtable_admin_v2::model::UpdateAuthorizedViewRequest;
let x = UpdateAuthorizedViewMetadata::new().set_original_request(UpdateAuthorizedViewRequest::default()/* use setters */);Sourcepub fn set_or_clear_original_request<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpdateAuthorizedViewRequest>,
pub fn set_or_clear_original_request<T>(self, v: Option<T>) -> Selfwhere
T: Into<UpdateAuthorizedViewRequest>,
Sets or clears the value of original_request.
Example
ⓘ
use google_cloud_bigtable_admin_v2::model::UpdateAuthorizedViewRequest;
let x = UpdateAuthorizedViewMetadata::new().set_or_clear_original_request(Some(UpdateAuthorizedViewRequest::default()/* use setters */));
let x = UpdateAuthorizedViewMetadata::new().set_or_clear_original_request(None::<UpdateAuthorizedViewRequest>);Sourcepub fn set_request_time<T>(self, v: T) -> Self
pub fn set_request_time<T>(self, v: T) -> Self
Sets the value of request_time.
Example
ⓘ
use wkt::Timestamp;
let x = UpdateAuthorizedViewMetadata::new().set_request_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_request_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_request_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of request_time.
Example
ⓘ
use wkt::Timestamp;
let x = UpdateAuthorizedViewMetadata::new().set_or_clear_request_time(Some(Timestamp::default()/* use setters */));
let x = UpdateAuthorizedViewMetadata::new().set_or_clear_request_time(None::<Timestamp>);Sourcepub fn set_finish_time<T>(self, v: T) -> Self
pub fn set_finish_time<T>(self, v: T) -> Self
Sets the value of finish_time.
Example
ⓘ
use wkt::Timestamp;
let x = UpdateAuthorizedViewMetadata::new().set_finish_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_finish_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_finish_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of finish_time.
Example
ⓘ
use wkt::Timestamp;
let x = UpdateAuthorizedViewMetadata::new().set_or_clear_finish_time(Some(Timestamp::default()/* use setters */));
let x = UpdateAuthorizedViewMetadata::new().set_or_clear_finish_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for UpdateAuthorizedViewMetadata
impl Clone for UpdateAuthorizedViewMetadata
Sourcefn clone(&self) -> UpdateAuthorizedViewMetadata
fn clone(&self) -> UpdateAuthorizedViewMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateAuthorizedViewMetadata
impl Debug for UpdateAuthorizedViewMetadata
Sourceimpl Default for UpdateAuthorizedViewMetadata
impl Default for UpdateAuthorizedViewMetadata
Sourcefn default() -> UpdateAuthorizedViewMetadata
fn default() -> UpdateAuthorizedViewMetadata
Returns the “default value” for a type. Read more
impl StructuralPartialEq for UpdateAuthorizedViewMetadata