#[non_exhaustive]pub struct UpdateAuthorizedViewRequest {
pub authorized_view: Option<AuthorizedView>,
pub update_mask: Option<FieldMask>,
pub ignore_warnings: bool,
/* private fields */
}Expand description
The request for UpdateAuthorizedView.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Required. The AuthorizedView to update. The name in authorized_view is
used to identify the AuthorizedView. AuthorizedView name must in this
format:
projects/{project}/instances/{instance}/tables/{table}/authorizedViews/{authorized_view}.
update_mask: Option<FieldMask>Optional. The list of fields to update.
A mask specifying which fields in the AuthorizedView resource should be
updated. This mask is relative to the AuthorizedView resource, not to the
request message. A field will be overwritten if it is in the mask. If
empty, all fields set in the request will be overwritten. A special value
* means to overwrite all fields (including fields not set in the
request).
ignore_warnings: boolOptional. If true, ignore the safety checks when updating the AuthorizedView.
Implementations
Sourceimpl UpdateAuthorizedViewRequest
impl UpdateAuthorizedViewRequest
Sets the value of authorized_view.
Example
use google_cloud_bigtable_admin_v2::model::AuthorizedView;
let x = UpdateAuthorizedViewRequest::new().set_authorized_view(AuthorizedView::default()/* use setters */);Sets or clears the value of authorized_view.
Example
use google_cloud_bigtable_admin_v2::model::AuthorizedView;
let x = UpdateAuthorizedViewRequest::new().set_or_clear_authorized_view(Some(AuthorizedView::default()/* use setters */));
let x = UpdateAuthorizedViewRequest::new().set_or_clear_authorized_view(None::<AuthorizedView>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateAuthorizedViewRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
use wkt::FieldMask;
let x = UpdateAuthorizedViewRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateAuthorizedViewRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_ignore_warnings<T: Into<bool>>(self, v: T) -> Self
pub fn set_ignore_warnings<T: Into<bool>>(self, v: T) -> Self
Sets the value of ignore_warnings.
Example
let x = UpdateAuthorizedViewRequest::new().set_ignore_warnings(true);Trait Implementations
Sourceimpl Clone for UpdateAuthorizedViewRequest
impl Clone for UpdateAuthorizedViewRequest
Sourcefn clone(&self) -> UpdateAuthorizedViewRequest
fn clone(&self) -> UpdateAuthorizedViewRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for UpdateAuthorizedViewRequest
impl Debug for UpdateAuthorizedViewRequest
Sourceimpl Default for UpdateAuthorizedViewRequest
impl Default for UpdateAuthorizedViewRequest
Sourcefn default() -> UpdateAuthorizedViewRequest
fn default() -> UpdateAuthorizedViewRequest
impl StructuralPartialEq for UpdateAuthorizedViewRequest