#[non_exhaustive]pub enum ReplicationState {
StateNotKnown,
Initializing,
PlannedMaintenance,
UnplannedMaintenance,
Ready,
ReadyOptimizing,
UnknownValue(UnknownValue),
}Expand description
Table replication states.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
StateNotKnown
The replication state of the table is unknown in this cluster.
Initializing
The cluster was recently created, and the table must finish copying over pre-existing data from other clusters before it can begin receiving live replication updates and serving Data API requests.
PlannedMaintenance
The table is temporarily unable to serve Data API requests from this cluster due to planned internal maintenance.
UnplannedMaintenance
The table is temporarily unable to serve Data API requests from this cluster due to unplanned or emergency maintenance.
Ready
The table can serve Data API requests from this cluster. Depending on replication delay, reads may not immediately reflect the state of the table in other clusters.
ReadyOptimizing
The table is fully created and ready for use after a restore, and is
being optimized for performance. When optimizations are complete, the
table will transition to READY state.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ReplicationState::value or ReplicationState::name.
Implementations