AutomatedBackupPolicy

Struct AutomatedBackupPolicy 

#[non_exhaustive]
pub struct AutomatedBackupPolicy { pub retention_period: Option<Duration>, pub frequency: Option<Duration>, pub locations: Vec<String>, /* private fields */ }
Defines an automated backup policy for a table

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
retention_period: Option<Duration>

Required. How long the automated backups should be retained. Values must be at least 3 days and at most 90 days.

frequency: Option<Duration>

How frequently automated backups should occur. The only supported value at this time is 24 hours. An undefined frequency is treated as 24 hours.

locations: Vec<String>

Optional. A list of Cloud Bigtable zones where automated backups are allowed to be created. If empty, automated backups will be created in all zones of the instance. Locations are in the format projects/{project}/locations/{zone}. This field can only set for tables in Enterprise Plus instances.

Implementations

Source

impl AutomatedBackupPolicy

pub fn new() -> Self

pub fn set_retention_period<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of retention_period.

Example
use wkt::Duration;
let x = AutomatedBackupPolicy::new().set_retention_period(Duration::default()/* use setters */);
pub fn set_or_clear_retention_period<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of retention_period.

Example
use wkt::Duration;
let x = AutomatedBackupPolicy::new().set_or_clear_retention_period(Some(Duration::default()/* use setters */));
let x = AutomatedBackupPolicy::new().set_or_clear_retention_period(None::<Duration>);
pub fn set_frequency<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of frequency.

Example
use wkt::Duration;
let x = AutomatedBackupPolicy::new().set_frequency(Duration::default()/* use setters */);
pub fn set_or_clear_frequency<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of frequency.

Example
use wkt::Duration;
let x = AutomatedBackupPolicy::new().set_or_clear_frequency(Some(Duration::default()/* use setters */));
let x = AutomatedBackupPolicy::new().set_or_clear_frequency(None::<Duration>);
pub fn set_locations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of locations.

Example
let x = AutomatedBackupPolicy::new().set_locations(["a", "b", "c"]);