#[non_exhaustive]pub enum Rule {
IncludeIfOlderThan(Box<Duration>),
}Expand description
Rules to specify what data is stored in this tier.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IncludeIfOlderThan(Box<Duration>)
Include cells older than the given age. For the infrequent access tier, this value must be at least 30 days.