Defines additional types related to AppProfile.
Modules
- data_
boost_ isolation_ read_ only - Defines additional types related to DataBoostIsolationReadOnly.
- multi_
cluster_ routing_ use_ any - Defines additional types related to MultiClusterRoutingUseAny.
Structs
- Data
Boost Isolation Read Only - Data Boost is a serverless compute capability that lets you run high-throughput read jobs and queries on your Bigtable data, without impacting the performance of the clusters that handle your application traffic. Data Boost supports read-only use cases with single-cluster routing.
- Multi
Cluster Routing UseAny - Read/write requests are routed to the nearest cluster in the instance, and will fail over to the nearest cluster that is available in the event of transient errors or delays. Clusters in a region are considered equidistant. Choosing this option sacrifices read-your-writes consistency to improve availability.
- Single
Cluster Routing - Unconditionally routes all read/write requests to a specific cluster. This option preserves read-your-writes consistency but does not improve availability.
- Standard
Isolation - Standard options for isolating this app profile’s traffic from other use cases.
Enums
- Isolation
- Options for isolating this app profile’s traffic from other use cases.
- Priority
- Possible priorities for an app profile. Note that higher priority writes can sometimes queue behind lower priority writes to the same tablet, as writes must be strictly sequenced in the durability log.
- Routing
Policy - The routing policy for all read/write requests that use this app profile. A value must be explicitly set.