Defines additional types related to AuthorizedView.
Structs
- Family
Subsets - Subsets of a column family that are included in this AuthorizedView.
- Subset
View - Defines a simple AuthorizedView that is a subset of the underlying Table.
Enums
- Authorized
View - The type of this AuthorizedView.
- Response
View - Defines a subset of an AuthorizedView’s fields.