#[non_exhaustive]pub enum Edition {
Unspecified,
Enterprise,
EnterprisePlus,
UnknownValue(UnknownValue),
}Expand description
Possible editions of an instance.
An edition is a specific tier of Cloud Bigtable. Each edition is tailored to different customer needs. Higher tiers offer more features and better performance.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The edition is unspecified. This is treated as ENTERPRISE.
Enterprise
The Enterprise edition. This is the default offering that is designed to meet the needs of most enterprise workloads.
EnterprisePlus
The Enterprise Plus edition. This is a premium tier that is designed for demanding, multi-tenant workloads requiring the highest levels of performance, scale, and global availability.
The nodes in the Enterprise Plus tier come at a higher cost than the Enterprise tier. Any Enterprise Plus features must be disabled before downgrading to Enterprise.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Edition::value or Edition::name.
Implementations