#[non_exhaustive]pub struct TieredStorageConfig {
pub infrequent_access: Option<TieredStorageRule>,
/* private fields */
}Expand description
Config for tiered storage. A valid config must have a valid TieredStorageRule. Otherwise the whole TieredStorageConfig must be unset. By default all data is stored in the SSD tier (only SSD instances can configure tiered storage).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.infrequent_access: Option<TieredStorageRule>Rule to specify what data is stored in the infrequent access(IA) tier. The IA tier allows storing more data per node with reduced performance.
Implementations
Sourceimpl TieredStorageConfig
impl TieredStorageConfig
pub fn new() -> Self
Sourcepub fn set_infrequent_access<T>(self, v: T) -> Selfwhere
T: Into<TieredStorageRule>,
pub fn set_infrequent_access<T>(self, v: T) -> Selfwhere
T: Into<TieredStorageRule>,
Sets the value of infrequent_access.
Example
ⓘ
use google_cloud_bigtable_admin_v2::model::TieredStorageRule;
let x = TieredStorageConfig::new().set_infrequent_access(TieredStorageRule::default()/* use setters */);Sourcepub fn set_or_clear_infrequent_access<T>(self, v: Option<T>) -> Selfwhere
T: Into<TieredStorageRule>,
pub fn set_or_clear_infrequent_access<T>(self, v: Option<T>) -> Selfwhere
T: Into<TieredStorageRule>,
Sets or clears the value of infrequent_access.
Example
ⓘ
use google_cloud_bigtable_admin_v2::model::TieredStorageRule;
let x = TieredStorageConfig::new().set_or_clear_infrequent_access(Some(TieredStorageRule::default()/* use setters */));
let x = TieredStorageConfig::new().set_or_clear_infrequent_access(None::<TieredStorageRule>);Trait Implementations
Sourceimpl Clone for TieredStorageConfig
impl Clone for TieredStorageConfig
Sourcefn clone(&self) -> TieredStorageConfig
fn clone(&self) -> TieredStorageConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TieredStorageConfig
impl Debug for TieredStorageConfig
Sourceimpl Default for TieredStorageConfig
impl Default for TieredStorageConfig
Sourcefn default() -> TieredStorageConfig
fn default() -> TieredStorageConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for TieredStorageConfig
impl Message for TieredStorageConfig
Sourceimpl PartialEq for TieredStorageConfig
impl PartialEq for TieredStorageConfig
impl StructuralPartialEq for TieredStorageConfig